Downloaded from https://airtable.com/app4Fo26j2vGYufCe/tbl0JN0LFtDi5SrS5/viwP9SeMB3V7vIUkW?blocks=hide

That Airtable is the source of truth.

To make changes, change the Airtable then redownload the CSV.
